03. Blending
************

.. figure:: images/03_alpha_blending.png
	:scale: 50 %
	:alt: 03_alpha_blending
	:align: center
	:figclass: align-center

	Alpha Blending

.. literalinclude:: ../../examples/GLWindow/03_alpha_blending.py
	:linenos:
